@@ -31,6 +31,8 @@ using System.Text;
 using Beagle.Util;
 using Beagle.Daemon;
 
+using SemWeb;
+
 namespace Beagle.Filters {
 	
 	public class FilterJpeg : FilterImage {
@@ -127,6 +129,20 @@ namespace Beagle.Filters {
 				}
 			}
 
+			byte [] xmp_data = header.GetRawXmp ();
+
+			if (xmp_data != null) {
+				int i;
+				for (i = 0; i < xmp_data.Length; i++)
+					if (xmp_data [i] == 0) {
+						i++;
+						break;
+					}
+
+				XmpFile xmp = new XmpFile (new MemoryStream (xmp_data, i, xmp_data.Length - i));
+				AddXmpProperties (xmp);
+			}
+
 			Finished (); // That's all folks...
 		}
 	}
