@@ -33,6 +33,7 @@ using GMime;
 
 using Beagle;
 using Beagle.Daemon;
+using Beagle.Util;
 
 namespace Beagle.Filters {
 
@@ -40,13 +41,15 @@ namespace Beagle.Filters {
 
 		private static bool gmime_initialized = false;
 
-		private GMime.Stream stream;
-		private GMime.Parser parser;
 		private GMime.Message message;
 		private PartHandler handler;
 
 		public FilterMail ()
 		{
+			// 1: Make email addresses non-keyword, add sanitized version
+			//    for eaching for parts of an email address.
+			SetVersion (1);
+
 			AddSupportedFlavor (FilterFlavor.NewFromMimeType ("message/rfc822"));
 		}
 
@@ -67,8 +70,11 @@ namespace Beagle.Filters {
 			if (mail_fd == -1)
 				throw new IOException (String.Format ("Unable to read {0} for parsing mail", info.FullName));
 
-			this.stream = new GMime.StreamFs (mail_fd);
-			this.parser = new GMime.Parser (stream);
+			GMime.StreamFs stream = new GMime.StreamFs (mail_fd);
+			GMime.Parser parser = new GMime.Parser (stream);
+			this.message = parser.ConstructMessage ();
+			stream.Dispose ();
+			parser.Dispose ();
 		}
 
 		private bool HasAttachments (GMime.Object mime_part)
@@ -86,8 +92,6 @@ namespace Beagle.Filters {
 
 		protected override void DoPullProperties ()
 		{
-			this.message = this.parser.ConstructMessage ();
-
 			string subject = GMime.Utils.HeaderDecodePhrase (this.message.Subject);
 			AddProperty (Property.New ("dc:title", subject));
 
@@ -97,7 +101,8 @@ namespace Beagle.Filters {
 			addrs = this.message.GetRecipients (GMime.Message.RecipientType.To);
 			foreach (GMime.InternetAddress ia in addrs) {
 				AddProperty (Property.NewKeyword ("fixme:to", ia.ToString (false)));
-				AddProperty (Property.NewKeyword ("fixme:to_address", ia.Addr));
+				AddProperty (Property.New ("fixme:to_address", ia.Addr));
+				AddProperty (Property.NewUnstored ("fixme:to_sanitized", StringFu.SanitizeEmail (ia.Addr)));
 				AddProperty (Property.New ("fixme:to_name", ia.Name));
 			}
 			addrs.Dispose ();
@@ -105,7 +110,8 @@ namespace Beagle.Filters {
 			addrs = this.message.GetRecipients (GMime.Message.RecipientType.Cc);
 			foreach (GMime.InternetAddress ia in addrs) {
 				AddProperty (Property.NewKeyword ("fixme:cc", ia.ToString (false)));
-				AddProperty (Property.NewKeyword ("fixme:cc_address", ia.Addr));
+				AddProperty (Property.New ("fixme:cc_address", ia.Addr));
+				AddProperty (Property.NewUnstored ("fixme:cc_sanitized", StringFu.SanitizeEmail (ia.Addr)));
 				AddProperty (Property.New ("fixme:cc_name", ia.Name));
 			}
 			addrs.Dispose ();
@@ -113,7 +119,8 @@ namespace Beagle.Filters {
 			addrs = GMime.InternetAddressList.ParseString (GMime.Utils.HeaderDecodePhrase (this.message.Sender));
 			foreach (GMime.InternetAddress ia in addrs) {
 				AddProperty (Property.NewKeyword ("fixme:from", ia.ToString (false)));
-				AddProperty (Property.NewKeyword ("fixme:from_address", ia.Addr));
+				AddProperty (Property.New ("fixme:from_address", ia.Addr));
+				AddProperty (Property.NewUnstored ("fixme:from_sanitized", StringFu.SanitizeEmail (ia.Addr)));
 				AddProperty (Property.New ("fixme:from_name", ia.Name));
 			}
 			addrs.Dispose ();
@@ -121,8 +128,17 @@ namespace Beagle.Filters {
 			if (HasAttachments (this.message.MimePart))
 				AddProperty (Property.NewFlag ("fixme:hasAttachments"));
 
-			string list_id = this.message.GetHeader ("List-Id");
+			// Store the message ID and references are unsearched
+			// properties.  They will be used to generate
+			// conversations in the frontend.
+			string msgid = this.message.GetHeader ("Message-Id");
+		        if (msgid != null)
+				AddProperty (Property.NewUnsearched ("fixme:msgid", GMime.Utils.DecodeMessageId (msgid)));
 
+			foreach (GMime.References refs in this.message.References)
+				AddProperty (Property.NewUnsearched ("fixme:reference", refs.Msgid));
+
+			string list_id = this.message.GetHeader ("List-Id");
 			if (list_id != null) {
 				// FIXME: Might need some additional parsing.
 				AddProperty (Property.NewKeyword ("fixme:mlist", GMime.Utils.HeaderDecodePhrase (list_id)));
@@ -160,16 +176,14 @@ namespace Beagle.Filters {
 		
 		public void Dispose ()
 		{
-			if (this.message != null)
+			if (this.handler != null && this.handler.Reader != null)
+				this.handler.Reader.Close ();
+			this.handler = null;
+
+			if (this.message != null) {
 				this.message.Dispose ();
-
-			if (this.stream != null) {
-				this.stream.Close ();
-				this.stream.Dispose ();
+				this.message = null;
 			}
-
-			if (this.parser != null)
-				this.parser.Dispose ();
 		}
 
 		private class PartHandler {
@@ -199,9 +213,9 @@ namespace Beagle.Filters {
 				GMime.Object part = null;
 				bool part_needs_dispose = false;
 
-				//for (int i = 0; i < depth; i++)
+				//for (int i = 0; i < this.depth; i++)
 				//  Console.Write ("  ");
-				//Console.WriteLine ("Content-Type: {0}", part.ContentType);
+				//Console.WriteLine ("Content-Type: {0}", mime_part.ContentType);
 			
 				++depth;
 
@@ -249,13 +263,10 @@ namespace Beagle.Filters {
 					throw new Exception (String.Format ("Unknown part type: {0}", part.GetType ()));
 
 				if (part != null) {
-					MemoryStream stream = null;
+					System.IO.Stream stream = null;
 					
-					using (GMime.DataWrapper content_obj = ((GMime.Part) part).ContentObject) {
-						stream = new MemoryStream ();
-						content_obj.WriteToStream (stream);
-						stream.Seek (0, SeekOrigin.Begin);
-					}
+					using (GMime.DataWrapper content_obj = ((GMime.Part) part).ContentObject)
+						stream = content_obj.Stream;
 
 					// If this is the only part and it's plain text, we
 					// want to just attach it to our filter instead of
