@@ -48,7 +48,7 @@ namespace Beagle.Daemon
 
 		static Hashtable remap_table = new Hashtable ();
 
-		static string arg_output, arg_tag;
+		static string arg_output, arg_tag, arg_source;
 
 		/////////////////////////////////////////////////////////
 		
@@ -173,6 +173,14 @@ namespace Beagle.Daemon
 					arg_disable_restart = true;
 					break;
 
+				case "--source":
+					if (next_arg == null)
+						break;
+
+					arg_source = next_arg;
+					++i;
+					break;
+
 				default:
 					string path = Path.IsPathRooted (arg) ? arg : Path.GetFullPath (arg);
 					
@@ -215,7 +223,7 @@ namespace Beagle.Daemon
 			// Set the IO priority to idle so we don't slow down the system
 			IoPriority.SetIdle ();
 			
-			driver = new LuceneIndexingDriver (arg_output);
+			driver = new LuceneIndexingDriver (arg_output, false);
 			driver.TextCache = (arg_cache_text) ? new TextCache (arg_output) : null;
 
 			backing_fa_store = new FileAttributesStore_Sqlite (driver.TopDirectory, driver.Fingerprint);
@@ -295,6 +303,26 @@ namespace Beagle.Daemon
 		
 		/////////////////////////////////////////////////////////////////
 
+		static void AddToRequest (IndexerRequest request, Indexable indexable)
+		{
+			// Disable filtering and only index file attributes
+			if (arg_disable_filtering)
+				indexable.Filtering = IndexableFiltering.Never;
+					
+			// Tag the item for easy identification (for say, removal)
+			if (arg_tag != null)
+				indexable.AddProperty (Property.NewKeyword("Tag", arg_tag));
+
+			if (arg_source == null) {
+				DirectoryInfo dir = new DirectoryInfo (StringFu.SanitizePath (arg_output));
+				arg_source = dir.Name;
+			}
+
+			indexable.Source = arg_source;
+
+			request.Add (indexable);
+		}
+
 		static IndexerReceipt [] FlushIndexer (IIndexer indexer, IndexerRequest request)
 		{
 			IndexerReceipt [] receipts;
@@ -336,7 +364,7 @@ namespace Beagle.Daemon
 
 			request.Clear (); // clear out the old request
 			foreach (Indexable i in pending_children) // and then add the children
-				request.Add (i);
+				AddToRequest (request, i);
 			
 			return receipts;
 		}
@@ -363,16 +391,8 @@ namespace Beagle.Daemon
 					indexable = new Indexable (uri);
 					indexable.Timestamp = file.LastWriteTimeUtc;
 					FSQ.AddStandardPropertiesToIndexable (indexable, file.Name, Guid.Empty, false);
-
-					// Disable filtering and only index file attributes
-					if (arg_disable_filtering)
-						indexable.Filtering = IndexableFiltering.Never;
 					
-					// Tag the item for easy identification (for say, removal)
-					if (arg_tag != null)
-						indexable.AddProperty (Property.NewKeyword("Tag", arg_tag));
-					
-					pending_request.Add (indexable);
+					AddToRequest (pending_request, indexable);
 					
 					if (pending_request.Count >= BATCH_SIZE) {
 						Logger.Log.Debug ("Flushing driver, {0} items in queue", pending_request.Count);
@@ -465,11 +485,17 @@ namespace Beagle.Daemon
 			string usage = 
 				"beagle-build-index: Build an index.\n" + 
 				"Web page: http://www.gnome.org/projects/beagle\n" +
-				"Copyright (C) 2005 Novell, Inc.\n\n";
+				"Copyright (C) 2005-2006 Novell, Inc.\n\n";
 			
 			usage += 
 				"Usage: beagle-build-index [OPTIONS] --target <index_path> <path> [path]\n\n" +
+
+				"** WARNING **\n" +
+				"beagle-build-index will *delete all existing data* within the target\n" +
+				"directory.  Ensure that the target path is set correctly before running.\n\n" +
+
 				"Options:\n" +
+				"  --source [name]\t\tThe index's source name.  Defaults to the target directory name\n" +
 				"  --remap [path1:path2]\t\tRemap data paths to fit target. \n" +
 				"  --tag [tag]\t\t\tTag index data for identification.\n" + 
 				"  --recursive\t\t\tCrawl source path recursivly.\n" + 
@@ -478,7 +504,8 @@ namespace Beagle.Daemon
 				"  --allow-pattern [pattern]\tOnly allow files that match the pattern to be indexed.\n" + 
 				"  --deny-pattern [pattern]\tKeep any files that match the pattern from being indexed.\n" + 
 				"  --disable-restart\t\tDon't restart when memory usage gets above a certain threshold.\n" +
-				"  --debug\t\t\tEcho verbose debugging information.\n";
+				"  --debug\t\t\tEcho verbose debugging information.\n\n";
+
 			
 			Console.WriteLine (usage);
 			Environment.Exit (0);
