@@ -276,8 +276,8 @@ namespace Beagle.Daemon.LifereaQueryable {
 			}
 
 			if (current_item == null) {
-				Logger.Log.Debug ("LifereaQ: Probably no more feeds left in " + feed_file);
-				Logger.Log.Debug ("Causing string = " + itemString);
+				//Logger.Log.Debug ("LifereaQ: Probably no more feeds left in " + feed_file);
+				//Logger.Log.Debug ("Causing string = " + itemString);
 				current_item = null;
 				is_valid_file = false;
 				reader.Close ();
