@@ -63,7 +63,9 @@ namespace Beagle.Daemon {
 			}
 		}
 
-		public TextCache (string storage_dir) 
+		public TextCache (string storage_dir) : this (storage_dir, false) { }
+
+		public TextCache (string storage_dir, bool read_only)
 		{
 			text_cache_dir = Path.Combine (storage_dir, "TextCache");
 			if (! Directory.Exists (text_cache_dir)) {
@@ -84,13 +86,59 @@ namespace Beagle.Daemon {
 			bool create_new_db = false;
 			if (! File.Exists (db_filename))
 				create_new_db = true;
-			
-			connection = new SqliteConnection ();
-			connection.ConnectionString = "version=" + ExternalStringsHack.SqliteVersion
-					+ ",URI=file:" + db_filename;
-			connection.Open ();
+
+			// Funky logic here to deal with sqlite versions.
+			//
+			// When sqlite 3 tries to open an sqlite 2 database,
+			// it will throw an SqliteException with SqliteError
+			// NOTADB when trying to execute a command.
+			//
+			// When sqlite 2 tries to open an sqlite 3 database,
+			// it will throw an ApplicationException when it
+			// tries to open the database.
+
+			try {
+				connection = Open (db_filename);
+			} catch (ApplicationException) {
+				Logger.Log.Warn ("Likely sqlite database version mismatch trying to open {0}.  Purging.", db_filename);
+				create_new_db = true;
+			}
+
+			if (!create_new_db) {
+				// Run a dummy query to see if we get a NOTADB error.  Sigh.
+				SqliteCommand command;
+				SqliteDataReader reader = null;
+
+				command = new SqliteCommand ();
+				command.Connection = connection;
+				command.CommandText =
+					"SELECT filename FROM uri_index WHERE uri='blah'";
+
+				try {
+					reader = ExecuteReaderOrWait (command);
+				} catch (SqliteException ex) {
+					if (ex.SqliteError == SqliteError.NOTADB) {
+						Logger.Log.Warn ("Likely sqlite database version mismatch trying to read from {0}.  Purging.", db_filename);
+						create_new_db = true;
+					} else
+						throw;
+				}
+
+				if (reader != null)
+					reader.Dispose ();
+				command.Dispose ();
+			}
 			
 			if (create_new_db) {
+				if (connection != null)
+					connection.Dispose ();
+
+				if (read_only)
+					throw new UnauthorizedAccessException (String.Format ("Unable to create read only text cache {0}", db_filename));
+
+				File.Delete (db_filename);
+				connection = Open (db_filename);
+
 				DoNonQuery ("CREATE TABLE uri_index (            " +
 					    "  uri      STRING UNIQUE NOT NULL,  " +
 					    "  filename STRING NOT NULL          " +
@@ -98,6 +146,15 @@ namespace Beagle.Daemon {
 			}
 		}
 
+		private SqliteConnection Open (string db_filename)
+		{
+			SqliteConnection connection = new SqliteConnection ();
+			connection.ConnectionString = "version=" + ExternalStringsHack.SqliteVersion
+				+ ",URI=file:" + db_filename;
+			connection.Open ();
+			return connection;
+		}
+
 		private static string UriToString (Uri uri)
 		{
 			return UriFu.UriToSerializableString (uri).Replace ("'", "''");
@@ -244,6 +301,9 @@ namespace Beagle.Daemon {
 
 			// We don't expect to need this again in the near future.
 			FileAdvise.FlushCache (stream);
+			
+			// Make files only readable by the owner.
+			Mono.Unix.Native.Syscall.chmod (path, (Mono.Unix.Native.FilePermissions) 384);
 
 			StreamWriter writer;
 			writer = new StreamWriter (stream);
